@@ -6,7 +6,7 @@ function(x,...)
   cat("\n")
   cat("Model:",x$model,"\n")
   cat("Number of objects:",x$nobj,"\n")
-  cat("Stess-1 value:",x$stress,"\n")
+  cat("Stress-1 value:",x$stress,"\n")
   cat("Number of iterations:",x$niter,"\n")
   cat("\n")
 }
